@@ -25,7 +25,10 @@ sub dump {
     }
     else {
         $ret .= "package ${namespace}::Schema;\n";
+        $ret .= "use strict;\n";
+        $ret .= "use warnings;\n";
         $ret .= "use Teng::Schema::Declare;\n";
+        $ret .= "base_row_class '$args{base_row_class}';\n" if $args{base_row_class};
         for my $table_info (sort { $a->name cmp $b->name } $inspector->tables) {
             $ret .= _render_table($table_info, \%args);
         }
@@ -127,6 +130,10 @@ Database handle from DBI.
 
 your project teng namespace.
 
+=item base_row_class
+
+Specify the default base row class for L<Teng::Schema::Declare>.
+
 =back
 
 =back
