@@ -14,6 +14,14 @@ sub create_sqlite {
             primary key ( id )
         )
     });
+    $dbh->do(q{
+        CREATE TABLE mock_basic_camelcase (
+            Id   integer,
+            Name text,
+            DeleteFg int(1) default 0,
+            primary key ( Id )
+        )
+    });
 }
 
 sub create_mysql {
